#import <UIKit/UIKit.h>
#import <EGUSDK/EGPayInfo.h>
#import <EGUSDK/EGRoleInfo.h>

#define KEY_SID @"key_sid"
#define KEY_USER_ID @"key_user_id"
#define KEY_TOKEN @"key_token"
#define KEY_USER_NAME @"key_user_name"
#define KEY_USER_NICKNAME @"key_user_nickname"
#define KEY_UNIX_TIME @"key_unix_time"
#define KEY_ERROR_MESSAGE @"key_error_message"
#define KEY_ORDER_ID @"key_order_id"

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSInteger, EG_EVENT_CODE) {
    EG_LOGIN_SUCCESS = 0, // 登录成功
    EG_LOGIN_FAILED,      // 登录失败
    /**
     SDK切换小号，2种处理该回调的方式，请对接方根据自身情况选择
     1. 对接方游戏支持运行时切换小号，即直接退出当前角色，取得以下新的uid和token刷新游戏，重新进入选服界面(此过程无需重新调用任何SDK接口，不需要调用+logout，也不需要调用+login)
     2. 对接方游戏不支持运行时切换小号，按照`EG_LOGOUT_SUCCESS`的处理方式处理，然后调用+logout后再调用+login，重新进行一遍登录流程
     */
    EG_SWITCH_SUBACCOUNT,
    /**
     SDK切换账号登出，对接方无需在此调用+logout、+login接口，做好游戏退出逻辑即可
     */
    EG_LOGOUT_SUCCESS,
    EG_PAY_SUCCESS,    // 支付成功
    EG_PAY_FAILED,     // 支付失败
    EG_PAY_CANCEL,     // 取消支付
};

typedef void (^SDKCallback)(EG_EVENT_CODE code, NSDictionary *_Nullable data);

@interface EGUSDK : NSObject

///（必接）初始化
+ (void)initWithCallback:(SDKCallback)callback;
///（必接）登录
+ (void)login;
///（必接）支付
+ (void)pay:(EGPayInfo *)payInfo;
///（必接）进入游戏时，提交角色信息
+ (void)onEnterGame:(EGRoleInfo *)roleInfo;
///（必接）游戏角色信息变化时，提交角色信息
+ (void)onRoleInfoChange:(EGRoleInfo *)roleInfo;
///（选接）退出登录，游戏内需要退出/注销时调用该接口通知SDK，
/// 注意调用该接口不会收到EG_LOGOUT_SUCCESS回调通知
/// 调用该接口退出后，请调用+login重新拉起登录
+ (void)logout;

NS_ASSUME_NONNULL_END

@end
